// src/index.ts
import * as crypto from "crypto";
var getABExperimentBucket = ({
  experimentName,
  uniqueId,
  treatmentSplit = 50,
  exposure = 100,
  treatmentVariantName = "treatment",
  controlVariantName = "control",
  ignoreVariantName = "ignore"
}) => {
  if (treatmentSplit < 0 || treatmentSplit > 100) {
    throw new Error(
      "treatmentSplit must be a number between 0 and 100 as it represents the percentage of users who will be bucketed into the treatment group."
    );
  }
  if (exposure < 0 || exposure > 100) {
    throw new Error(
      "exposure must be a number between 0 and 100 as it represents the percentage of users who will be bucketed into the experiment."
    );
  }
  try {
    const digest = crypto.createHash("sha256");
    const hashBytes = digest.update(uniqueId).digest();
    const hashedId = BigInt(
      `0x${Buffer.from(hashBytes).subarray(0, 8).toString("hex")}`
    );
    const normalizedHashedId = Number(hashedId) / Number(BigInt("0xFFFFFFFFFFFFFFFF"));
    const randomNum = Math.floor(normalizedHashedId * 1e4);
    if (randomNum / 100 >= exposure)
      return {
        experimentName,
        uniqueId,
        resolvedVariant: ignoreVariantName
      };
    const resolvedVariant = randomNum % 100 < treatmentSplit ? treatmentVariantName : controlVariantName;
    return {
      experimentName,
      uniqueId,
      resolvedVariant
    };
  } catch (error) {
    return {
      experimentName,
      uniqueId,
      resolvedVariant: null,
      isError: true,
      error
    };
  }
};
export {
  getABExperimentBucket
};
